import { declare } from '@babel/helper-plugin-utils';
import proposalAsyncDoExpressions from '@babel/plugin-proposal-async-do-expressions';
import proposalClassProperties from '@babel/plugin-proposal-class-properties';
import proposalClassStaticBlock from '@babel/plugin-proposal-class-static-block';
import proposalDoExpressions from '@babel/plugin-proposal-do-expressions';
import proposalFunctionBind from '@babel/plugin-proposal-function-bind';
import proposalFunctionSent from '@babel/plugin-proposal-function-sent';
import proposalJsonStrings from '@babel/plugin-proposal-json-strings';
import proposalPartialApplication from '@babel/plugin-proposal-partial-application';
import proposalPipelineOperator from '@babel/plugin-proposal-pipeline-operator';
import proposalPrivateMethods from '@babel/plugin-proposal-private-methods';
import proposalPrivatePropertyInObject from '@babel/plugin-proposal-private-property-in-object';
import proposalRecordAndTuple from '@babel/plugin-proposal-record-and-tuple';
import proposalThrowExpression from '@babel/plugin-proposal-throw-expressions';
import syntaxDecorators from '@babel/plugin-syntax-decorators';
import syntaxTypeScript from '@babel/plugin-syntax-typescript';
import { compare } from 'compare-versions';

var syntaxV8intrinsic = declare(function (api) {
    api.assertVersion(7);
    return {
        name: 'v8intrinsic',
        manipulateOptions: function (_opts, parserOpts) {
            parserOpts.plugins.push('v8intrinsic');
        },
    };
});

var NODE_VERSION = process.versions.node;
var IS_RECORD_TUPLE_SUPPORTED = compare(NODE_VERSION, '14.6', '>=');

var index = declare(function (api, _a) {
    var classLoose = _a.classLoose, decoratorsBeforeExport = _a.decoratorsBeforeExport, _b = _a.decoratorsLegacy, decoratorsLegacy = _b === void 0 ? true : _b, isTSX = _a.isTSX, _c = _a.pipelineOperator, pipelineOperator = _c === void 0 ? 'minimal' : _c, _d = _a.recordTuplePolyfill, recordTuplePolyfill = _d === void 0 ? IS_RECORD_TUPLE_SUPPORTED : _d, _e = _a.recordTupleSyntaxType, recordTupleSyntaxType = _e === void 0 ? 'hash' : _e;
    api.assertVersion(7);
    return {
        plugins: [
            [
                syntaxDecorators,
                {
                    decoratorsBeforeExport: decoratorsBeforeExport,
                    legacy: decoratorsLegacy,
                },
            ],
            [
                syntaxTypeScript,
                {
                    isTSX: isTSX,
                },
            ],
            syntaxV8intrinsic,
            proposalAsyncDoExpressions,
            [
                proposalClassStaticBlock,
                {
                    loose: classLoose,
                },
            ],
            [
                proposalClassProperties,
                {
                    loose: classLoose,
                },
            ],
            proposalDoExpressions,
            proposalFunctionBind,
            proposalFunctionSent,
            proposalJsonStrings,
            proposalPartialApplication,
            [
                proposalPipelineOperator,
                {
                    proposal: pipelineOperator,
                },
            ],
            [
                proposalPrivateMethods,
                {
                    loose: classLoose,
                },
            ],
            [
                proposalPrivatePropertyInObject,
                {
                    loose: classLoose,
                },
            ],
            recordTuplePolyfill && [
                proposalRecordAndTuple,
                {
                    importPolyfill: !!recordTuplePolyfill,
                    polyfillModuleName: typeof recordTuplePolyfill === 'string'
                        ? recordTuplePolyfill
                        : undefined,
                    syntaxType: recordTupleSyntaxType,
                },
            ],
            proposalThrowExpression,
        ].filter(Boolean),
        // no need to override if it has been enabled
        overrides: isTSX
            ? undefined
            : [
                {
                    test: /\.[jt]sx$/,
                    plugins: [
                        [
                            syntaxTypeScript,
                            {
                                isTSX: true,
                            },
                        ],
                    ],
                },
            ],
    };
});

export default index;
